@@ -132,6 +132,7 @@ class Streams:
     stream_name,
     schema_kind,
     schema,
+    indexes=None,
     description=None,
     allow_manual_writes=None,
     use_log=None,
@@ -148,6 +149,7 @@ class Streams:
         'streamName': format_entity_name(stream_name),
         'schemaKind': schema_kind,
         'schema': schema,
+        'indexes': indexes,
         'description': description,
         'allowManualWrites': allow_manual_writes,
         'useLog': use_log,
@@ -164,6 +166,7 @@ class Streams:
           $streamName: String!
           $schemaKind: StreamSchemaKind!,
           $schema: String!,
+          $indexes: String,
           $description: String,
           $allowManualWrites: Boolean,
           $useLog: Boolean,
@@ -179,6 +182,7 @@ class Streams:
             streamName: $streamName,
             schemaKind: $schemaKind,
             schema: $schema,
+            indexes: $indexes,
             description: $description,
             allowManualWrites: $allowManualWrites,
             useLog: $useLog,
