@@ -11,6 +11,8 @@ DEFAULT_WRITE_DELAY_MS = 1000
 DEFAULT_WRITE_PIPELINE_STATE_DELAY_MS = 30000
 DEFAULT_SUBSCRIBE_POLL_AT_LEAST_EVERY_MS = 60000
 DEFAULT_SUBSCRIBE_POLL_AT_MOST_EVERY_MS = 1000
+DEFAULT_QUERY_WAREHOUSE_TIMEOUT_MS = 60 * 1000
+DEFAULT_QUERY_WAREHOUSE_MAX_BYTES_SCANNED = 10000000000
 MAX_WRITE_SIZE_BYTES = 10000000
 MAX_WRITE_SIZE_COUNT = 10000
 
